@@ -277,6 +277,7 @@ class Window:
         self.search_bar = None
         self.status_bar = None
         self.help_bar = None
+        self.sort_order = utils.build_sort_order(common.DEFAULT_SORT_ORDER)
         self.search = Searcher('',
                                self.conf.bool(common.SETTING_GROUP_GENERAL,
                                               common.SETTING_SEARCH_CASE_SENSITIVE),
@@ -508,15 +509,22 @@ class Window:
             x += len(label) + 1
         self.help_bar.noutrefresh()
 
+    def update_sorting(self):
+        for part in self.search.text.split(' '):
+            if part.startswith('sort:'):
+                self.sort_order = utils.build_sort_order(part.split(':', 1)[1])
+                break
+        self.tasks.sort(key=lambda t: utils.sort_fnc(t, self.sort_order))
+
     def update_tasks(self):
         self.tasks = []
         for source in self.sources:
             self.tasks += [(task, source) for task in source.tasks]
-        self.tasks.sort(key=utils.sort_fnc)
 
         self.apply_search()
 
     def apply_search(self):
+        self.update_sorting()
         self.filtered_tasks = [(task, source) for task, source in self.tasks
                                if self.search.match(task)]
         self.rebuild_task_lines()
